==> haskell-http-client-0.6.4-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-client
version: 0.6.4
id: http-client-0.6.4-LC2XTclyTBtLSxSxXQXavF
key: http-client-0.6.4-LC2XTclyTBtLSxSxXQXavF
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/snoyberg/http-client
synopsis: An HTTP client engine
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-client>.
category: Network
abi: b6bef8293eece96a010dea2e967f6ee1
exposed: True
exposed-modules:
    Network.HTTP.Client Network.HTTP.Client.Internal
    Network.HTTP.Client.MultipartFormData
hidden-modules: Network.HTTP.Client.Body
                Network.HTTP.Client.Connection Network.HTTP.Client.Cookies
                Network.HTTP.Client.Core Network.HTTP.Client.Headers
                Network.HTTP.Client.Manager Network.HTTP.Client.Request
                Network.HTTP.Client.Response Network.HTTP.Client.Types
                Network.HTTP.Client.Util Network.HTTP.Proxy
                Network.PublicSuffixList.Lookup Network.PublicSuffixList.Types
                Network.PublicSuffixList.Serialize
                Network.PublicSuffixList.DataStructure Data.KeyedPool
import-dirs: /usr/lib/ghc-8.6.5/site-local/http-client-0.6.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/http-client-0.6.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/http-client-0.6.4
hs-libraries: HShttp-client-0.6.4-LC2XTclyTBtLSxSxXQXavF
depends:
    array-0.5.3.0 base-4.12.0.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk containers-0.6.0.1
    cookie-0.4.4-BFYr3M2B0n8F3gqLxXgKNx deepseq-1.4.4.0
    exceptions-0.10.2-EJs0RkZsum56ksbfDqbl1F filepath-1.4.2.1
    ghc-prim-0.5.3 http-types-0.12.3-4KWln6jzZFqKSBXaEIoMvB
    memory-0.14.18-IbWiQctDwmh73RXfnLR7k6
    mime-types-0.1.0.9-2hmZJ5CmRudCuwA0xwTABk
    network-2.8.0.0-FZwMvc7MoUJBpGGHu2O13h
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    random-1.1-3ypV4EIycgb35PKjTYYr5q stm-2.5.0.0
    streaming-commons-0.2.1.1-Cz1nN7Sucqo90QnDfH7On0 text-1.2.3.1
    time-1.8.0.2 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-http-client/html/http-client.haddock
haddock-html: /usr/share/doc/haskell-http-client/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-client-0.6.4-15-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-client
version: 0.6.4
id: http-client-0.6.4-2vvZT4nV8ZwJDNuwGeFyhx
key: http-client-0.6.4-2vvZT4nV8ZwJDNuwGeFyhx
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/snoyberg/http-client
synopsis: An HTTP client engine
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-client>.
category: Network
abi: 9bfe700262c1701b1e82e700d84dbc32
exposed: True
exposed-modules:
    Network.HTTP.Client Network.HTTP.Client.Internal
    Network.HTTP.Client.MultipartFormData
hidden-modules: Network.HTTP.Client.Body
                Network.HTTP.Client.Connection Network.HTTP.Client.Cookies
                Network.HTTP.Client.Core Network.HTTP.Client.Headers
                Network.HTTP.Client.Manager Network.HTTP.Client.Request
                Network.HTTP.Client.Response Network.HTTP.Client.Types
                Network.HTTP.Client.Util Network.HTTP.Proxy
                Network.PublicSuffixList.Lookup Network.PublicSuffixList.Types
                Network.PublicSuffixList.Serialize
                Network.PublicSuffixList.DataStructure Data.KeyedPool
import-dirs: /usr/lib/ghc-8.6.5/site-local/http-client-0.6.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/http-client-0.6.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/http-client-0.6.4
hs-libraries: HShttp-client-0.6.4-2vvZT4nV8ZwJDNuwGeFyhx
depends:
    array-0.5.3.0 base-4.12.0.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk containers-0.6.0.1
    cookie-0.4.4-BFYr3M2B0n8F3gqLxXgKNx deepseq-1.4.4.0
    exceptions-0.10.2-Gj8cIuYcXhQEAym4RMvM4g filepath-1.4.2.1
    ghc-prim-0.5.3 http-types-0.12.3-BsfSThCiYntF94Mfs0JU92
    memory-0.14.18-IbWiQctDwmh73RXfnLR7k6
    mime-types-0.1.0.9-2hmZJ5CmRudCuwA0xwTABk
    network-2.8.0.0-1M86biZqFSo3ZnJTr6WevT
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    random-1.1-3ypV4EIycgb35PKjTYYr5q stm-2.5.0.0
    streaming-commons-0.2.1.1-5VTVyP30rE49RCYG9xHT9 text-1.2.3.1
    time-1.8.0.2 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-http-client/html/http-client.haddock
haddock-html: /usr/share/doc/haskell-http-client/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
